@@ -1,5 +1,6 @@
 """Common utilities for the OpenDAPI CLI."""
 
+import base64
 import functools
 import json
 import os
@@ -152,18 +153,6 @@ class Schemas:
 
         raise ValueError(f"Unknown validator class: {validator_cls}")
 
-    @property
-    def as_dict(self):
-        """Return the schemas as a dictionary."""
-        return {
-            "teams": self.teams,
-            "datastores": self.datastores,
-            "purposes": self.purposes,
-            "dapi": self.dapi,
-            "subjects": self.subjects,
-            "categories": self.categories,
-        }
-
 
 def check_command_invocation_in_root():
     """Check if the `opendapi` CLI command is invoked from the root of the repository."""
@@ -203,6 +192,7 @@ def get_opendapi_config_from_root(
         if validate_config:
             check_if_opendapi_config_is_valid(config)
         return config
+
     except FileNotFoundError as exc:
         print_cli_output(
             f"  The {CONFIG_FILEPATH_FROM_ROOT_DIR} file does not exist. "
@@ -248,6 +238,21 @@ def pretty_print_errors(errors: List[Exception]):
             print_cli_output(err)
 
 
+ENCODED_BREADCRUMB_PREFIX = "OPENDAPI_BREADCRUMB::"
+
+
+def print_encoded_breadcrumbs(message: str):
+    """Prints the error message encoded in a way for the server"""
+    base64_bytes = base64.b64encode(message.encode("utf-8"))
+    base64_message = f"{ENCODED_BREADCRUMB_PREFIX}{base64_bytes.decode('utf-8')}"
+    print_cli_output(base64_message)
+
+
+def highlight_message(message: str):
+    """Highlights the message"""
+    return f"\n{'>' * 30}\n\n{message}\n\n{'>' * 30}\n"
+
+
 def print_cli_output(
     message: str,
     color: str = "green",
@@ -266,7 +271,7 @@ def print_cli_output(
         logger.info(message)
 
     # Markdown message
-    if markdown_file and not no_markdown:
+    if markdown_file and not no_markdown:  # pragma: no cover
         with open(
             markdown_file,
             "a",
