@@ -1,8 +1,11 @@
 """
-CLI for generating, validating and enriching DAPI files: `opendapi github buildkite run`
-"""
+CLI for collecting dapi file information at the base commit andhead commit,
+analyzing them, uploading the required information to the DAPI server,
+and then starting the server driven CICD.
 
-# pylint: disable=duplicate-code
+This command is invoked in a buildkite CI runner for a github repo and a single runtime:
+`opendapi github buildkite run`
+"""
 
 import click
 
@@ -13,14 +16,10 @@ from opendapi.cli.options import (
     dev_options,
     generation_options,
     git_options,
-    minimal_schema_options,
     opendapi_run_options,
 )
 from opendapi.cli.repos.github.options import repo_options
-from opendapi.cli.repos.github.runners.buildkite.enrich import cli as enrich_cli
-from opendapi.cli.repos.github.runners.buildkite.generate import cli as generate_cli
 from opendapi.cli.repos.github.runners.buildkite.options import runner_options
-from opendapi.cli.repos.github.runners.buildkite.register import cli as register_cli
 from opendapi.cli.repos.github.runners.buildkite.server_sync import (
     cli as server_sync_cli,
 )
@@ -33,7 +32,6 @@ from opendapi.cli.repos.github.runners.buildkite.server_sync import (
 @dev_options
 @generation_options
 @git_options
-@minimal_schema_options
 @opendapi_run_options
 # github repo options
 @repo_options
@@ -41,20 +39,19 @@ from opendapi.cli.repos.github.runners.buildkite.server_sync import (
 @runner_options
 def cli(**kwargs):
     """
-    This command combines the `generate`, `enrich`, and `register` commands
-    conditionally for a Github remote repo running on a Buildkite hosted runner.
+    CLI for collecting dapi file information at the base commit andhead commit,
+    analyzing them, uploading the required information to the DAPI server,
+    and then starting the server driven CICD.
 
-    This interacts with the DAPI server, and thus needs
-    the server host and API key as environment variables or CLI options.
+    This command is invoked in a buildkite CI runner for a github repo and a single runtime:
+    `opendapi github buildkite run`
     """
 
     # Run register last to ensure the DAPI files are registered and unregistered
     # Register will also validate the DAPI files in the backend
+
     commands = {
         "server-sync": server_sync_cli,
-        "generate": generate_cli,
-        "enrich": enrich_cli,
-        "register": register_cli,
     }
 
     repo_runner_run_cli(commands, kwargs)
