@@ -1,6 +1,31 @@
 """Constants and reusable definitions for the OpenDAPI Python client."""
 
+from __future__ import annotations
+
 from enum import Enum
+from typing import List
+
+
+class ORMIntegration(Enum):
+    """Enum for the ORM integration"""
+
+    ACTIVERECORD = "activerecord"
+    DBT = "dbt"
+    PRISMA = "prisma"
+    PYNAMODB = "pynamodb"
+    SQLALCHEMY = "sqlalchemy"
+    SEQUELIZE = "sequelize"
+    TYPEORM = "typeorm"
+    PROTOBUF = "protobuf"
+    NO_ORM_FALLBACK = "no_orm_fallback"
+
+    @classmethod
+    def integrations(cls) -> List[ORMIntegration]:
+        """Return the list of integrations"""
+        return [
+            integration for integration in cls if integration != cls.NO_ORM_FALLBACK
+        ]
+
 
 TEAMS_SUFFIX = [".teams.yaml", ".teams.yml", ".teams.json"]
 DATASTORES_SUFFIX = [".datastores.yaml", ".datastores.yml", ".datastores.json"]
@@ -26,7 +51,8 @@ ALL_OPENDAPI_SUFFIXES = (
     + GITHUB_ACTIONS_SUFFIX
 )
 
-OPENDAPI_URL = "https://opendapi.org/"
+OPENDAPI_DOMAIN = "opendapi.org"
+OPENDAPI_URL = f"https://{OPENDAPI_DOMAIN}/"
 OPENDAPI_SPEC_URL = OPENDAPI_URL + "spec/{version}/{entity}.json"
 
 PLACEHOLDER_TEXT = "placeholder text"
@@ -34,7 +60,7 @@ PLACEHOLDER_TEXT = "placeholder text"
 CONFIG_FILEPATH_FROM_ROOT_DIR = "opendapi.config.yaml"
 DEFAULT_DAPIS_DIR = "dapis"
 GITHUB_ACTIONS_FILEPATH_FROM_ROOT_DIR = ".github/workflows/opendapi_ci.yml"
-DEFAULT_DAPI_SERVER_HOSTNAME = "https://api.wovencollab.com"
+DEFAULT_DAPI_SERVER_HOSTNAME = "https://api.woven.dev"
 
 REFS_PREFIXES = {
     r"^refs/heads/",
@@ -47,7 +73,6 @@ class HTTPMethod(Enum):
 
     GET = "GET"
     POST = "POST"
-    DELETE = "DELETE"
 
 
 class OpenDAPIEntity(Enum):
@@ -104,6 +129,12 @@ DAPI_ORM_EXTRACTED_FIELDS_SCHEMA = {
                 "is_nullable": {
                     "type": "boolean",
                 },
+                "enum_values": {
+                    "type": "array",
+                    "items": {
+                        "type": "string",
+                    },
+                },
             },
             "required": ["name", "data_type"],
         }
@@ -154,11 +185,14 @@ DAPI_CLIENT_REQUIRED_MINIMAL_SCHEMA = {
                 "description": {
                     "type": ["string", "null"],
                 },
-                "is_pii": {
-                    "type": ["boolean", "null"],
+                "enum_values": {
+                    "type": "array",
+                    "items": {
+                        "type": "string",
+                    },
                 },
             },
-            "required": ["name", "data_type", "is_nullable", "description", "is_pii"],
+            "required": ["name", "data_type", "is_nullable", "description"],
         }
     },
     "type": "object",
