@@ -1,4 +1,4 @@
-# pylint: disable=too-many-instance-attributes
+# pylint: disable=too-many-instance-attributes, no-name-in-module
 """Validator class for DAPI and related files"""
 
 from __future__ import annotations
@@ -13,16 +13,17 @@ from typing import Dict, Iterable, List, Optional, Set, Tuple, Type, Union
 
 import requests
 from deepmerge import STRATEGY_END, Merger
-from jsonschema import ValidationError as JsonValidationError
-from jsonschema import validate as jsonschema_validate
+from jsonschema_rs import ValidationError as JsonValidationError
+from jsonschema_rs import validator_for as jsonschema_validator_for
 
-from opendapi.adapters.git import GitCommitStasher
+from opendapi.adapters.git import ChangeTriggerEvent, GitCommitStasher
 from opendapi.cli.common import Schemas
 from opendapi.config import OpenDAPIConfig
-from opendapi.defs import DEFAULT_DAPIS_DIR, OpenDAPIEntity
+from opendapi.defs import DEFAULT_DAPIS_DIR, CommitType, OpenDAPIEntity
 from opendapi.logging import LogCounterKey, increment_counter
 from opendapi.utils import (
     YAML,
+    convert_ruemelyaml_commentedmap_to_dict,
     fetch_schema,
     find_files_with_suffix,
     prune_additional_properties,
@@ -38,6 +39,22 @@ from opendapi.validators.defs import (
 )
 
 
+@contextmanager
+def _maybe_git_commit_stash(
+    root_dir: str,
+    commit_already_checked_out: bool,
+    commit_type: CommitType,
+    change_trigger_event: ChangeTriggerEvent,
+):
+    """Stash the git commit if necessary"""
+    if commit_type is not CommitType.CURRENT and not commit_already_checked_out:
+        commit_sha = change_trigger_event.commit_type_to_sha(commit_type)
+        with GitCommitStasher(root_dir, "opendapi-validate", commit_sha):
+            yield
+    else:
+        yield
+
+
 class BaseValidator(ABC):
     """Base validator class for DAPI and related files"""
 
@@ -52,34 +69,53 @@ class BaseValidator(ABC):
     ] = []
 
     # Paths to disallow new entries when merging
-    MERGE_DISALLOW_NEW_ENTRIES_PATH: List[List[str]] = []
+    MERGE_DISALLOW_NEW_ENTRIES_PATH: List[
+        List[Union[str, int, MergeKeyCompositeIDParams.IgnoreListIndexType]]
+    ] = []
 
     SPEC_VERSION: str = NotImplemented
     ENTITY: OpenDAPIEntity = NotImplemented
     INTEGRATION_TYPE: IntegrationType = IntegrationType.STATIC
 
-    def __init__(
+    def __init__(  # pylint: disable=too-many-arguments
         self,
         *,
         root_dir: str,
+        runtime: str,
+        change_trigger_event: ChangeTriggerEvent,
+        commit_type: CommitType,
         enforce_existence_at: Optional[FileSet] = None,
         override_config: Optional[OpenDAPIConfig] = None,
         schema_to_prune_generated: Optional[Dict] = None,
-        commit_sha: Optional[str] = None,
     ):
         self.schema_cache = {}
         self.yaml = YAML()
         self.root_dir = root_dir
+        self.runtime = runtime
+        self.change_trigger_event = change_trigger_event
+        self.commit_type = commit_type
         self.enforce_existence_at = enforce_existence_at
         self.config: OpenDAPIConfig = override_config or OpenDAPIConfig(root_dir)
         self.schema_to_prune_generated = schema_to_prune_generated
-        self.commit_sha = commit_sha
+        # helpers
+        self._jsonschema_ref_to_validator = {}
 
         # we run file collection at __init__ time,
         # so that there is no confusion what the results will be if
         # collected_files is accessed later on
         _ = self.collected_files
 
+    @property
+    def commit_sha(self) -> Optional[str]:
+        """Get the commit SHA"""
+        # for current state, there is nothing to check out - otherwise we get the commit sha,
+        # and we enforce that it exists
+        return (
+            None
+            if self.commit_type is CommitType.CURRENT
+            else self.change_trigger_event.commit_type_to_sha(self.commit_type)
+        )
+
     @property
     def base_destination_dir(self) -> str:
         """Get the base directory for the spec files"""
@@ -101,13 +137,27 @@ class BaseValidator(ABC):
         raise ValueError(f"Invalid file set: {fileset}")  # pragma: no cover
 
     @classmethod
-    def _get_merger(cls):
+    def _get_merger(
+        cls,
+        merge_unique_lookup_keys_override: Optional[
+            List[Tuple[List[str], MergeKeyCompositeIDParams]]
+        ] = None,
+    ):
         """
         Get the merger object for deepmerge
 
         NOTE: merge() mutates - defend if necessary
         """
 
+        def _autoupdate_merge_strategy_for_non_mergeable_lists(  # pylint: disable=unused-argument
+            config, path, base, nxt
+        ):
+            """
+            For non-mergeable lists - detected via the path being in MERGE_DISALLOW_NEW_ENTRIES_PATH
+            - we just return the base
+            """
+            return base if path in cls.MERGE_DISALLOW_NEW_ENTRIES_PATH else STRATEGY_END
+
         def _get_match_using_merge_keys(
             list_to_match: List, itm: Dict, merge_keys: List[MergeKeyCompositeIDParams]
         ) -> Optional[Dict]:
@@ -147,8 +197,11 @@ class BaseValidator(ABC):
                 return STRATEGY_END
 
             result = []
+            merge_unique_lookup_keys = (
+                merge_unique_lookup_keys_override or cls.MERGE_UNIQUE_LOOKUP_KEYS
+            )
             autoupdate_unique_merge_keys_for_path = [
-                v for k, v in cls.MERGE_UNIQUE_LOOKUP_KEYS if k == path
+                v for k, v in merge_unique_lookup_keys if k == path
             ]
 
             # lets shy away from automatically deduping, and only scrub the
@@ -205,7 +258,14 @@ class BaseValidator(ABC):
                 #       merging logic depending on path (if path doesnt match,
                 #       return STRATEGY_END), and defaulting to `append_unique`
                 #       should none match
-                (list, [_autoupdate_merge_strategy_for_dict_lists, "append_unique"]),
+                (
+                    list,
+                    [
+                        _autoupdate_merge_strategy_for_dict_lists,
+                        _autoupdate_merge_strategy_for_non_mergeable_lists,
+                        "append_unique",
+                    ],
+                ),
                 (dict, "merge"),
                 (set, "union"),
             ],
@@ -229,15 +289,6 @@ class BaseValidator(ABC):
         except ValueError as exc:
             raise ValidationError(f"Unsupported file type for {file}") from exc
 
-    @contextmanager
-    def _maybe_git_commit_stash(self):
-        """Stash the git commit if necessary"""
-        if self.commit_sha:
-            with GitCommitStasher(self.root_dir, "opendapi-validate", self.commit_sha):
-                yield
-        else:
-            yield
-
     def _get_file_contents_for_suffix(self, suffixes: List[str]):
         """Get the contents of all files in the root directory with given suffixes"""
         files = self._get_files_for_suffix(suffixes)
@@ -262,6 +313,10 @@ class BaseValidator(ABC):
             self.schema_cache[jsonschema_ref] = self.schema_cache.get(
                 jsonschema_ref
             ) or fetch_schema(jsonschema_ref)
+            self._jsonschema_ref_to_validator[jsonschema_ref] = (
+                self._jsonschema_ref_to_validator.get(jsonschema_ref)
+                or jsonschema_validator_for(self.schema_cache[jsonschema_ref])
+            )
         except requests.exceptions.RequestException as exc:
             error_message = f"Error fetching schema {jsonschema_ref}: {str(exc)}"
             raise ValidationError(error_message) from exc
@@ -276,13 +331,18 @@ class BaseValidator(ABC):
         jsonschema_ref = content["schema"]
 
         try:
-            schema = self._fetch_schema(jsonschema_ref)
+            self._fetch_schema(jsonschema_ref)
         except ValidationError as exc:
             error_message = f"Validation error for {file}: \n{str(exc)}"
             raise ValidationError(error_message) from exc
 
         try:
-            jsonschema_validate(content, schema)
+            # might get rueyaml CommentedMap or CommentedSeq etc., which
+            # doesnt play nice with the rust impl
+            ensured_dict_content = convert_ruemelyaml_commentedmap_to_dict(content)
+            self._jsonschema_ref_to_validator[jsonschema_ref].validate(
+                ensured_dict_content
+            )
         except JsonValidationError as exc:
             error_message = f"Validation error for {file}: \n{str(exc)}"
             raise ValidationError(error_message) from exc
@@ -306,24 +366,22 @@ class BaseValidator(ABC):
     @functools.cached_property
     def original_file_state(self) -> Dict[str, Dict]:
         """Collect the original file state"""
-        with self._maybe_git_commit_stash():
-            return self._get_file_contents_for_suffix(self.SUFFIX)
+        return self._get_file_contents_for_suffix(self.SUFFIX)
 
     @functools.cached_property
     def generated_file_state(self) -> Dict[str, Dict]:
         """Collect the raw generated file state"""
-        with self._maybe_git_commit_stash():
-            base_gen_files = self._get_base_generated_files()
-            if self.schema_to_prune_generated:
-                for file, content in base_gen_files.items():
-                    # does no validation, just prunes the additional properties.
-                    base_gen_files[file] = prune_additional_properties(
-                        content, self.schema_to_prune_generated
-                    )
-            return {
-                self.config.assert_dapi_location_is_valid(file): base_content
-                for file, base_content in base_gen_files.items()
-            }
+        base_gen_files = self._get_base_generated_files()
+        if self.schema_to_prune_generated:
+            for file, content in base_gen_files.items():
+                # does no validation, just prunes the additional properties.
+                base_gen_files[file] = prune_additional_properties(
+                    content, self.schema_to_prune_generated
+                )
+        return {
+            self.config.assert_dapi_location_is_valid(file): base_content
+            for file, base_content in base_gen_files.items()
+        }
 
     @functools.cached_property
     def merged_file_state(self) -> Dict[str, Dict]:
@@ -462,21 +520,31 @@ class BaseValidator(ABC):
         organized_results = defaultdict(dict)
         for result in results:
             if result.filepath in organized_results[result.entity]:
+                # NOTE: we have seen this happen if the HEAD ORIGINAL is missing context -
+                #       so it goes to fallback validator, but then when we run the other validators
+                #       that pick up on the actual model it creates another dapi for HEAD GENERATED
+                #       for that validator.
                 raise ValueError(
-                    f"Multiple results for {result.filepath} in {result.entity}"
+                    f"Multiple results for {result.filepath} in {result.entity}."
+                    "This generally happens if the same file is processed by multiple validators, "
+                    "which in turn generally happens if the committed file is missing integration "
+                    "info in the context section, which is usually user error. Delete the m"
                 )
             organized_results[result.entity][result.filepath] = result
         return organized_results
 
     @classmethod
-    def run_validators(  # pylint: disable=too-many-arguments
+    def run_validators(  # pylint: disable=too-many-arguments, too-many-locals
         cls,
         validators: Iterable[Type[BaseValidator]],
         root_dir: str,
+        runtime: str,
+        change_trigger_event: ChangeTriggerEvent,
+        commit_type: CommitType,
         enforce_existence_at: Optional[FileSet] = None,
         override_config: Optional[OpenDAPIConfig] = None,
         minimal_schemas: Optional[Schemas] = None,
-        commit_sha: Optional[str] = None,
+        commit_already_checked_out: bool = False,
         # integration specific flags
         runtime_skip_generation: bool = False,
         dbt_skip_generation: bool = False,
@@ -489,28 +557,33 @@ class BaseValidator(ABC):
         """
         collected_files = []
         errors = []
-        for validator in validators:
-            kwargs = {
-                "root_dir": root_dir,
-                "enforce_existence_at": enforce_existence_at,
-                "override_config": override_config,
-                "schema_to_prune_generated": (
-                    minimal_schemas.minimal_schema_for(validator)
-                    if minimal_schemas
-                    else None
-                ),
-                "commit_sha": commit_sha,
-            }
+        with _maybe_git_commit_stash(
+            root_dir, commit_already_checked_out, commit_type, change_trigger_event
+        ):
+            for validator in validators:
+                kwargs = {
+                    "root_dir": root_dir,
+                    "runtime": runtime,
+                    "enforce_existence_at": enforce_existence_at,
+                    "override_config": override_config,
+                    "schema_to_prune_generated": (
+                        minimal_schemas.minimal_schema_for(validator)
+                        if minimal_schemas
+                        else None
+                    ),
+                    "change_trigger_event": change_trigger_event,
+                    "commit_type": commit_type,
+                }
 
-            if validator.INTEGRATION_TYPE is IntegrationType.RUNTIME:
-                kwargs["skip_generation"] = runtime_skip_generation
-            elif validator.INTEGRATION_TYPE is IntegrationType.DBT:
-                kwargs["skip_generation"] = dbt_skip_generation
+                if validator.INTEGRATION_TYPE is IntegrationType.RUNTIME:
+                    kwargs["skip_generation"] = runtime_skip_generation
+                elif validator.INTEGRATION_TYPE is IntegrationType.DBT:
+                    kwargs["skip_generation"] = dbt_skip_generation
 
-            inst = validator(**kwargs)
-            try:
-                collected_files.extend(inst.get_validated_files().values())
-            except MultiValidationError as e:
-                errors.append(e)
+                inst = validator(**kwargs)
+                try:
+                    collected_files.extend(inst.get_validated_files().values())
+                except MultiValidationError as e:
+                    errors.append(e)
 
-        return cls._organize(collected_files), errors
+            return cls._organize(collected_files), errors
