@@ -1,16 +1,18 @@
 """DAPI validator module"""
 
+from __future__ import annotations
+
 import copy
 from abc import abstractmethod
 from collections import Counter
 from functools import cached_property
-from typing import Dict, Generic, List, Tuple, TypeVar, Union
+from typing import Dict, Generic, List, Tuple, Type, TypeVar, Union
 
 from opendapi.config import construct_project_full_path, get_project_path_from_full_path
-from opendapi.defs import DAPI_SUFFIX, OPENDAPI_SPEC_URL, OpenDAPIEntity
+from opendapi.defs import DAPI_SUFFIX, OPENDAPI_SPEC_URL, OpenDAPIEntity, ORMIntegration
 from opendapi.logging import logger
 from opendapi.models import ConfigParam, OverrideConfig, PlaybookConfig, ProjectConfig
-from opendapi.utils import find_files_with_suffix
+from opendapi.utils import find_files_with_suffix, sort_dapi_fields
 from opendapi.validators.base import (
     BaseValidator,
     MultiValidationError,
@@ -29,7 +31,7 @@ class BaseDapiValidator(BaseValidator):
     Abstract base validator class for DAPI files
     """
 
-    INTEGRATION_NAME: str = NotImplementedError
+    INTEGRATION_NAME: ORMIntegration = NotImplementedError
     SUFFIX = DAPI_SUFFIX
     SPEC_VERSION = "0-0-1"
     ENTITY = OpenDAPIEntity.DAPI
@@ -41,7 +43,10 @@ class BaseDapiValidator(BaseValidator):
             MergeKeyCompositeIDParams,
         ]
     ] = [
-        (["fields"], MergeKeyCompositeIDParams(required=[["name"]])),
+        (
+            ["fields"],
+            MergeKeyCompositeIDParams(required=[["name"], ["data_type"]]),
+        ),
         (
             ["datastores", "sources"],
             MergeKeyCompositeIDParams(
@@ -71,10 +76,38 @@ class BaseDapiValidator(BaseValidator):
     # Paths to disallow new entries when merging
     MERGE_DISALLOW_NEW_ENTRIES_PATH: List[List[str]] = [["fields"]]
 
+    _REGISTRY: Dict[ORMIntegration, Type[BaseDapiValidator]] = {}
+
+    def __init_subclass__(cls, **kwargs):
+        super().__init_subclass__(**kwargs)
+        # another base class
+        if cls.INTEGRATION_NAME is NotImplementedError:
+            return
+
+        if cls.INTEGRATION_NAME in cls._REGISTRY:  # pragma: nocover
+            raise ValueError(f"Integration {cls.INTEGRATION_NAME} already registered")
+
+        cls._REGISTRY[cls.INTEGRATION_NAME] = cls
+
+    @staticmethod
+    def get_validator(integration_name: ORMIntegration) -> Type[BaseDapiValidator]:
+        """Get the validator for the integration"""
+        return BaseDapiValidator._REGISTRY[integration_name]
+
     def _get_field_names(self, content: dict) -> List[str]:
         """Get the field names"""
         return [field["name"] for field in content["fields"]]
 
+    def _retention_reference_is_a_valid_field(self, file: str, content: Dict):
+        """Validate if the retention reference is a valid field"""
+        retention_reference = content.get("retention_reference")
+        if retention_reference and retention_reference not in self._get_field_names(
+            content
+        ):
+            raise ValidationError(
+                f"Retention reference '{retention_reference}' not a valid field in '{file}'"
+            )
+
     def _validate_primary_key_is_a_valid_field(self, file: str, content: Dict):
         """Validate if the primary key is a valid field"""
         primary_key = content.get("primary_key") or []
@@ -85,6 +118,16 @@ class BaseDapiValidator(BaseValidator):
                     f"Primary key element '{key}' not a valid field in '{file}'"
                 )
 
+    def _validate_field_names_unique(self, file: str, content: Dict):
+        """Validate if the field names are unique"""
+        field_names = self._get_field_names(content)
+        duplicates = {name for name in field_names if field_names.count(name) > 1}
+        if duplicates:
+            raise ValidationError(
+                f"Field names must be unique in '{file}'"
+                f"Duplicate field names: {duplicates}"
+            )
+
     def _validate_field_data_subjects_and_categories_unique(
         self, file: str, content: Dict
     ):
@@ -134,7 +177,7 @@ class BaseDapiValidator(BaseValidator):
     def settings(self) -> ProjectConfig:
         """Get the settings from the config file for this integration"""
         settings = copy.deepcopy(
-            self.config.get_integration_settings(self.INTEGRATION_NAME)
+            self.config.get_integration_settings(self.INTEGRATION_NAME, self.runtime)
         )
 
         override_config = settings.get(ConfigParam.PROJECTS.value, {}).get(
@@ -160,32 +203,81 @@ class BaseDapiValidator(BaseValidator):
         self._validate_primary_key_is_a_valid_field(file, content)
         self._validate_field_data_subjects_and_categories_unique(file, content)
         self._is_personal_data_is_direct_identifier_matched(file, content)
+        self._validate_field_names_unique(file, content)
+        self._retention_reference_is_a_valid_field(file, content)
 
     @property
     def base_destination_dir(self) -> str:
         return self.root_dir
 
+    def filter_dapis(self, dapis: Dict[str, Dict]) -> Dict[str, Dict]:
+        """Get the owned DAPIs"""
+        return {
+            file: content
+            for file, content in dapis.items()
+            # we want the BaseDapiValidator to be able to collect all Dapis
+            # but all impls of BaseDapiValidator should only validate their own
+            # integration
+            # then, we want to match integrations directly, but if an integration is missing,
+            # then we want to collect it with the fallback validator
+            if (
+                type(self) is BaseDapiValidator  # pylint: disable=unidiomatic-typecheck
+                or (integration := content.get("context", {}).get("integration"))
+                == self.INTEGRATION_NAME.value  # pylint: disable=no-member
+                or not integration
+                and self.INTEGRATION_NAME is ORMIntegration.NO_ORM_FALLBACK
+            )
+        }
+
     @cached_property
     def original_file_state(self) -> Dict[str, Dict]:
         """
         Get the contents of all files in the root directory,
         if they are part of the integration
         """
-        with self._maybe_git_commit_stash():
-            dapis = self._get_file_contents_for_suffix(self.SUFFIX)
-            return {
-                file: content
-                for file, content in dapis.items()
-                # we want the BaseDapiValidator to be able to collect all Dapis
-                # but all impls of BaseDapiValidator should only validate their own
-                # integration
-                if (
-                    type(self)  # pylint: disable=unidiomatic-typecheck
-                    is BaseDapiValidator
-                    or content.get("context", {}).get("integration")
-                    == self.INTEGRATION_NAME
-                )
-            }
+        dapis = self._get_file_contents_for_suffix(self.SUFFIX)
+        og_file_state = self.filter_dapis(dapis)
+        # Temporary fix for historical_ept_rates
+        # KB Note: remove this once the bug is fixed
+        for dapi in og_file_state.values():
+            if dapi.get("urn", "").endswith("historical_ept_rates"):  # pragma: nocover
+                seen_fields = set()
+                deduped_fields = []
+                for field in dapi["fields"]:
+                    if field["name"] not in seen_fields:
+                        deduped_fields.append(field)
+                        seen_fields.add(field["name"])
+                dapi["fields"] = deduped_fields
+
+        # lets sort the fields for original just as we do
+        # for generated making comparisons easier
+        for dapi in og_file_state.values():
+            dapi["fields"] = sort_dapi_fields(dapi["fields"])
+
+        # NOTE: CLEANUP - lets remove is_pii, access from each field
+        for dapi in og_file_state.values():
+            for field in dapi["fields"]:
+                field.pop("is_pii", None)
+                field.pop("access", None)
+
+        return og_file_state
+
+    @cached_property
+    def generated_file_state(self) -> Dict[str, Dict]:
+        """Get the generated file state"""
+        gen_files = super().generated_file_state
+        # we will sort the fields for generated so that nested
+        # fields are clustered in a coherent way
+        for dapi in gen_files.values():
+            dapi["fields"] = sort_dapi_fields(dapi["fields"])
+
+        # NOTE: CLEANUP - lets remove is_pii, access from each field
+        for dapi in gen_files.values():
+            for field in dapi["fields"]:
+                field.pop("is_pii", None)
+                field.pop("access", None)
+
+        return gen_files
 
     @staticmethod
     def add_non_playbook_datastore_fields(
@@ -198,6 +290,39 @@ class BaseDapiValidator(BaseValidator):
                 ds["retention_days"] = None
         return datastores
 
+    @classmethod
+    def add_default_non_generated_schema_portions(cls, dapi: dict) -> dict:
+        """Add the default schema portion to the dapi"""
+        dapi["fields"] = [
+            {
+                "description": None,
+                "data_subjects_and_categories": [],
+                "sensitivity_level": None,
+                "is_personal_data": None,
+                "is_direct_identifier": None,
+                **field,
+            }
+            for field in dapi["fields"]
+        ]
+        return {
+            "schema": OPENDAPI_SPEC_URL.format(version=cls.SPEC_VERSION, entity="dapi"),
+            "type": "entity",
+            "owner_team_urn": None,
+            "datastores": DapiValidator.add_non_playbook_datastore_fields(
+                {
+                    "sources": [],
+                    "sinks": [],
+                }
+            ),
+            "description": None,
+            "privacy_requirements": {
+                "dsr_access_endpoint": None,
+                "dsr_deletion_endpoint": None,
+            },
+            "context": {},
+            **dapi,
+        }
+
     def _get_base_generated_files(self) -> Dict[str, Dict]:
         """Set Autoupdate templates in {file_path: content} format"""
         return {
@@ -258,6 +383,41 @@ class BaseDapiValidator(BaseValidator):
             }
         }
 
+    @classmethod
+    def merge(cls, base: Dict, nxt: Dict) -> Dict:
+        """Merge the base and next dictionaries"""
+        # NOTE: this is a hack to allow for in flight PRs that have the diverged
+        #       dapis to go through merging without considering data type
+        if base.get("urn", "").rsplit(".", 1)[-1] in (
+            "boms",
+            "catalog_item_inventory_snapshots",
+            "end_of_month_adjustments",
+            "milestones",
+            "onboarding_flows",
+            "shopify_inventory_items",
+            "shopify_product_images",
+            "shopify_product_options",
+            "shopify_product_variants",
+            "shopify_products",
+            "trackstar_inventory_snapshots",
+            "weighted_average_costs",
+        ):
+            merge_unique_lookup_keys_override = copy.deepcopy(
+                cls.MERGE_UNIQUE_LOOKUP_KEYS
+            )
+            for i, (path, _) in enumerate(merge_unique_lookup_keys_override):
+                if path == ["fields"]:
+                    merge_unique_lookup_keys_override[i] = (
+                        path,
+                        MergeKeyCompositeIDParams(required=[["name"]]),
+                    )
+        else:
+            merge_unique_lookup_keys_override = None
+
+        return cls._get_merger(merge_unique_lookup_keys_override).merge(
+            copy.deepcopy(base), copy.deepcopy(nxt)
+        )
+
 
 class DapiValidator(BaseDapiValidator, Generic[ProjectInfoType]):
     """
@@ -295,6 +455,16 @@ class DapiValidator(BaseDapiValidator, Generic[ProjectInfoType]):
     def validate_projects(self, projects: List[ProjectInfoType]):
         """Validate the projects"""
 
+    def filter_dapis(self, dapis: Dict[str, Dict]) -> Dict[str, Dict]:
+        """Filter the dapis with projects as well"""
+        integration_filtered_dapis = super().filter_dapis(dapis)
+        projects = self.selected_projects()
+        return {
+            fp: dapi
+            for project in projects
+            for fp, dapi in project.filter_dapis(integration_filtered_dapis).items()
+        }
+
 
 class RuntimeDapiValidator(DapiValidator[ProjectInfoType], Generic[ProjectInfoType]):
     """
@@ -327,9 +497,9 @@ class RuntimeDapiValidator(DapiValidator[ProjectInfoType], Generic[ProjectInfoTy
     def _unskipped_get_base_generated_files(self) -> Dict[str, Dict]:
         """Build the base template for autoupdate"""
 
-    @abstractmethod
     def _skipped_get_base_generated_files(self) -> Dict[str, Dict]:
         """Build the base template for autoupdate"""
+        return self.original_file_state
 
     def _get_base_generated_files(self) -> Dict[str, Dict]:
         """Build the base template for autoupdate"""
@@ -347,6 +517,11 @@ class RuntimeDapiValidator(DapiValidator[ProjectInfoType], Generic[ProjectInfoTy
 
         return self._unskipped_get_base_generated_files()
 
+    @property
+    def _generate_skipped(self) -> bool:
+        """Return True if generation is skipped"""
+        return self._skip_generation
+
 
 class PackageScopedDapiValidatorBase(BaseDapiValidator):
     """Base class for DAPI validators that are scoped to packages."""
