@@ -14,9 +14,8 @@ from opendapi.config import (
     construct_owner_team_urn_from_playbooks,
     is_model_in_allowlist,
 )
-from opendapi.defs import OPENDAPI_SPEC_URL
 from opendapi.models import PlaybookConfig
-from opendapi.validators.dapi.base import PackageScopedDapiValidatorBase
+from opendapi.validators.dapi.base import ORMIntegration, PackageScopedDapiValidatorBase
 from opendapi.validators.dapi.models import PackageScopedProjectInfo
 
 
@@ -107,14 +106,7 @@ class Column:
         return {
             "name": self.name,
             "data_type": self.type,
-            "description": None,
-            "is_pii": None,
             "is_nullable": self.is_nullable,
-            "access": "private",
-            "data_subjects_and_categories": [],
-            "sensitivity_level": None,
-            "is_personal_data": None,
-            "is_direct_identifier": None,
         }
 
 
@@ -222,7 +214,7 @@ class ExtendModelTable(Table):
 class SequelizeDapiValidator(PackageScopedDapiValidatorBase):
     """Validator class for DAPI files created for Sequelize v6 models"""
 
-    INTEGRATION_NAME = "sequelize"
+    INTEGRATION_NAME = ORMIntegration.SEQUELIZE
     LOOKUP_FILE_SUFFIXES: List[str] = [".js"]
 
     @staticmethod
@@ -337,29 +329,25 @@ class SequelizeDapiValidator(PackageScopedDapiValidatorBase):
         result = {}
 
         for table in self.get_sequelize_tables():
-            result[table.construct_dapi_location()] = {
-                "schema": OPENDAPI_SPEC_URL.format(
-                    version=self.SPEC_VERSION,
-                    entity="dapi",
-                ),
-                "type": "entity",
-                "urn": table.construct_urn(),
-                "owner_team_urn": table.construct_team_urn(),
-                "description": None,
-                "datastores": table.construct_datastores(),
-                "fields": [field.for_dapi() for field in table.columns],
-                "primary_key": [c.name for c in table.columns if c.is_primary_key],
-                "context": {
-                    "service": table.app_name,
-                    "integration": "sequelize",
-                    "rel_model_path": os.path.relpath(
-                        table.filename, table.construct_dapi_location()
-                    ),
-                },
-                "privacy_requirements": {
-                    "dsr_access_endpoint": None,
-                    "dsr_deletion_endpoint": None,
-                },
-            }
+            result[table.construct_dapi_location()] = (
+                self.add_default_non_generated_schema_portions(
+                    {
+                        "urn": table.construct_urn(),
+                        "owner_team_urn": table.construct_team_urn(),
+                        "datastores": table.construct_datastores(),
+                        "fields": [field.for_dapi() for field in table.columns],
+                        "primary_key": [
+                            c.name for c in table.columns if c.is_primary_key
+                        ],
+                        "context": {
+                            "service": table.app_name,
+                            "integration": "sequelize",
+                            "rel_model_path": os.path.relpath(
+                                table.filename, table.construct_dapi_location()
+                            ),
+                        },
+                    }
+                )
+            )
 
         return result
