@@ -19,11 +19,10 @@ from opendapi.config import (
     get_project_path_from_full_path,
     is_model_in_allowlist,
 )
-from opendapi.defs import OPENDAPI_SPEC_URL
 from opendapi.logging import logger
 from opendapi.models import OverrideConfig
 from opendapi.utils import find_files_with_suffix
-from opendapi.validators.dapi.base import RuntimeDapiValidator
+from opendapi.validators.dapi.base import ORMIntegration, RuntimeDapiValidator
 from opendapi.validators.dapi.models import ProjectInfo
 
 if TYPE_CHECKING:
@@ -68,14 +67,7 @@ class SqlAlchemyProjectInfo(ProjectInfo):
                     "data_type": self._sqlalchemy_column_type_to_dapi_datatype(
                         column.type
                     ),
-                    "description": None,
                     "is_nullable": column.nullable,
-                    "is_pii": None,
-                    "access": "private",
-                    "data_subjects_and_categories": [],
-                    "sensitivity_level": None,
-                    "is_personal_data": None,
-                    "is_direct_identifier": None,
                 }
             )
         fields.sort(key=lambda x: x["name"])
@@ -174,7 +166,7 @@ class SqlAlchemyProjectInfo(ProjectInfo):
 class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
     """Validator class for DAPI files created for SQLAlchemy datasets"""
 
-    INTEGRATION_NAME = "sqlalchemy"
+    INTEGRATION_NAME = ORMIntegration.SQLALCHEMY
 
     # App identifiers are comma separated values specified as the following:
     # "path/to/module.py:metadata"
@@ -200,7 +192,7 @@ class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
     def build_urn_for_table(self, project: SqlAlchemyProjectInfo, table_name) -> str:
         """Build the urn for the table"""
         return (
-            f"{project.org_name_snakecase}.{self.INTEGRATION_NAME}."
+            f"{project.org_name_snakecase}.{self.INTEGRATION_NAME.value}."
             f"{project.service_name}.{table_name}"
         )
 
@@ -300,46 +292,35 @@ class SqlAlchemyDapiValidator(RuntimeDapiValidator[SqlAlchemyProjectInfo]):
             # Note this includes the schema as well
             table_full_name = table["fullname"]
 
-            result[project.construct_dapi_location(table_full_name)] = {
-                "schema": OPENDAPI_SPEC_URL.format(
-                    version=self.SPEC_VERSION,
-                    entity="dapi",
-                ),
-                "urn": self.build_urn_for_table(project, table_full_name),
-                "type": "entity",
-                "description": None,
-                "owner_team_urn": construct_owner_team_urn_from_playbooks(
-                    project.override.playbooks, table_full_name, project.full_path
-                ),
-                "datastores": self.build_datastores_for_table(project, table_full_name),
-                "fields": table["fields"],
-                "primary_key": table["primary_key"],
-                "context": {
-                    "integration": self.INTEGRATION_NAME,
-                    "service": project.service_name,
-                    "rel_model_path": os.path.relpath(
-                        project.artifact_full_path,
-                        os.path.dirname(
-                            project.construct_dapi_location(table_full_name)
+            result[project.construct_dapi_location(table_full_name)] = (
+                self.add_default_non_generated_schema_portions(
+                    {
+                        "urn": self.build_urn_for_table(project, table_full_name),
+                        "owner_team_urn": construct_owner_team_urn_from_playbooks(
+                            project.override.playbooks,
+                            table_full_name,
+                            project.full_path,
                         ),
-                    ),
-                },
-                "privacy_requirements": {
-                    "dsr_access_endpoint": None,
-                    "dsr_deletion_endpoint": None,
-                },
-            }
+                        "datastores": self.build_datastores_for_table(
+                            project, table_full_name
+                        ),
+                        "fields": table["fields"],
+                        "primary_key": table["primary_key"],
+                        "context": {
+                            "integration": self.INTEGRATION_NAME.value,
+                            "service": project.service_name,
+                            "rel_model_path": os.path.relpath(
+                                project.artifact_full_path,
+                                os.path.dirname(
+                                    project.construct_dapi_location(table_full_name)
+                                ),
+                            ),
+                        },
+                    }
+                )
+            )
         return result
 
-    def _skipped_get_base_generated_files(self) -> Dict[str, Dict]:
-        """Build the base template for autoupdate"""
-        projects = self.selected_projects()
-        return {
-            fp: dapi
-            for project in projects
-            for fp, dapi in project.filter_dapis(self.original_file_state).items()
-        }
-
     def _unskipped_get_base_generated_files(self) -> Dict[str, Dict]:
         """Build the base template for autoupdate"""
         projects = self.selected_projects()
