@@ -1,6 +1,5 @@
 """Teams validator module"""
 
-import functools
 from collections import Counter
 from typing import Dict, List, Tuple, Union
 
@@ -11,6 +10,7 @@ from opendapi.validators.base import (
     ValidationError,
 )
 from opendapi.validators.defs import FileSet, MergeKeyCompositeIDParams
+from opendapi.weakref import weak_lru_cache
 
 
 class SubjectsValidator(BaseValidator):
@@ -40,10 +40,7 @@ class SubjectsValidator(BaseValidator):
         ),
     ]
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
-
-    @functools.lru_cache()
+    @weak_lru_cache()
     def _get_file_state_subject_urn_counts(self, fileset: FileSet) -> Counter:
         """Collect all the subject urns"""
         return Counter(
